using System;
using System.Collections.Generic;
using System.Text;
using System.Runtime.InteropServices;
using System.IO;
 
namespace ADX_IE_Shared_Memory_CS
{
    [ComVisible(false)]
    public class GlobalData
    {
        private static GlobalData instance = null;
		private string lastOutputPath;
		private MySharedData optionPageData;

		private const int FILE_LOCKED = 0;
		private const int RADIO_OPTION = 1;
		private const int CHECK_OPTION_1 = 2;
		private const int CHECK_OPTION_2 = 3;
		private const int LIST_OPTION = 4;
		private const int STRING_OPTION = 5;

        public GlobalData()
        {
			//System.Diagnostics.Debugger.Break();
			string outputPath = Path.Combine(
				Environment.GetFolderPath(Environment.SpecialFolder.InternetCache), "Low");
			outputPath = Path.Combine(outputPath, "MyIEOptionPage");
			if (!Directory.Exists(outputPath))
				Directory.CreateDirectory(outputPath);
			this.lastOutputPath = outputPath;

			this.optionPageData = new MySharedData("MyIEOptionPage", 512, 10);

			this.optionPageData[FILE_LOCKED] = 0;
			this.optionPageData[RADIO_OPTION] = 0;
			this.optionPageData[CHECK_OPTION_1] = false;
			this.optionPageData[CHECK_OPTION_2] = false;
			this.optionPageData[LIST_OPTION] = 0;
			this.optionPageData[STRING_OPTION] = "Default";
        }

        private void ConnectOptions()
        {
            if (this.optionPageData == null)
            {
                this.optionPageData = new MySharedData("MyIEOptionPage", 512, 10);

                this.optionPageData[FILE_LOCKED] = 0;
                this.optionPageData[RADIO_OPTION] = 0;
                this.optionPageData[CHECK_OPTION_1] = false;
                this.optionPageData[CHECK_OPTION_2] = false;
                this.optionPageData[LIST_OPTION] = 0;
                this.optionPageData[STRING_OPTION] = "Default";
            }
        }

        public static GlobalData Instance
        {
            get
            {
                if (instance == null)
                    instance = new GlobalData();
                return instance;
            }
        }

		public void CloseOptions()
		{
			lock (instance)
			{
				if (this.optionPageData != null)
					try
					{
						SaveOptions();
					}
					finally
					{
						this.optionPageData.Dispose();
						this.optionPageData = null;
					}
			}
		}

		public void RefreshOptions(IEBarModule module)
		{
			lock (instance)
			{
                ConnectOptions();

				module.RadioOptions = (int)this.optionPageData[RADIO_OPTION];
				module.CheckOption1 = (bool)this.optionPageData[CHECK_OPTION_1];
				module.CheckOption2 = (bool)this.optionPageData[CHECK_OPTION_2];
				module.ListOption = (int)this.optionPageData[LIST_OPTION];
				module.StringOption = (string)this.optionPageData[STRING_OPTION];
			}
		}

		public void UpdateOptions(IEBarModule module)
		{
			lock (instance)
			{
                ConnectOptions();

                this.optionPageData[RADIO_OPTION] = module.RadioOptions;
				this.optionPageData[CHECK_OPTION_1] = module.CheckOption1;
				this.optionPageData[CHECK_OPTION_2] = module.CheckOption2;
				this.optionPageData[LIST_OPTION] = module.ListOption;
				this.optionPageData[STRING_OPTION] = module.StringOption;
				SaveOptions();
			}
		}

		private void SaveOptions()
		{
			if ((int)this.optionPageData[FILE_LOCKED] == 0)
			{
				this.optionPageData[FILE_LOCKED] = 1;
				try
				{
					string outputFile = Path.Combine(lastOutputPath, "myoptions.cfg");
					using (StreamWriter sw = new StreamWriter(outputFile, false))
					{
						sw.Write(this.optionPageData[RADIO_OPTION]);
						sw.Write(sw.NewLine);
						sw.Write(this.optionPageData[CHECK_OPTION_1]);
						sw.Write(sw.NewLine);
						sw.Write(this.optionPageData[CHECK_OPTION_2]);
						sw.Write(sw.NewLine);
						sw.Write(this.optionPageData[LIST_OPTION]);
						sw.Write(sw.NewLine);
						sw.Write(this.optionPageData[STRING_OPTION]);
					}
				}
				finally
				{
					this.optionPageData[FILE_LOCKED] = 0;
				}
			}
		}

		public void LoadOptions()
		{
            ConnectOptions();

            if ((int)this.optionPageData[FILE_LOCKED] == 0)
			{
				this.optionPageData[FILE_LOCKED] = 1;
				try
				{
					string outputFile = Path.Combine(lastOutputPath, "myoptions.cfg");
					if (File.Exists(outputFile))
					{
						using (StreamReader sr = new StreamReader(outputFile))
						{
							string line;
							line = sr.ReadLine();
							this.optionPageData[RADIO_OPTION] = Convert.ToInt32(line.Trim());
							line = sr.ReadLine();
							this.optionPageData[CHECK_OPTION_1] = Convert.ToBoolean(line.Trim());
							line = sr.ReadLine();
							this.optionPageData[CHECK_OPTION_2] = Convert.ToBoolean(line.Trim());
							line = sr.ReadLine();
							this.optionPageData[LIST_OPTION] = Convert.ToInt32(line.Trim());
							line = sr.ReadLine();
							this.optionPageData[STRING_OPTION] = line.Trim();
						}
					}
				}
				finally
				{
					this.optionPageData[FILE_LOCKED] = 0;
				}
			}
		}
    }
}

